@@ -11,6 +11,12 @@ from climlab.dynamics import MeridionalDiffusion
 from climlab.domain.initial import surface_state
 from scipy import integrate
 
+#  A lot of this should be re-written / simplified
+#  using more up-to-date climlab APIs for coupling processes together
+#  Making sure that each subprocess properly declares inputs and diagnostics
+
+#  For example, the basic EBM should be created with something like
+#  ebm = climlab.couple([asr,olr,diff])
 
 class EBM(EnergyBudget):
     """A parent class for all Energy-Balance-Model classes.
@@ -378,14 +384,18 @@ class EBM_seasonal(EBM):
                 :include-source:
 
         """
+        if ai is None:
+            no_albedo_feedback = True
+            ai = 0. # ignored but need to set a number
+        else:
+            no_albedo_feedback = False
         super(EBM_seasonal, self).__init__(a0=a0, a2=a2, ai=ai, **kwargs)
-        sfc = self.domains['Ts']
-        self.add_subprocess('insolation',
-                            DailyInsolation(domains=sfc, **self.param))
         self.param['a0'] = a0
         self.param['a2'] = a2
-        if ai is None:
-            # No albedo feedback
+        sfc = self.domains['Ts']
+        self.add_subprocess('insolation',
+                        DailyInsolation(domains=sfc, **self.param))
+        if no_albedo_feedback:
             # Remove unused parameters here for clarity
             _ = self.param.pop('ai')
             _ = self.param.pop('Tf')
