@@ -63,8 +63,7 @@
 #         - anything in the `input` dictionary of `subprocname` will remain fixed
 #==============================================================================
 
-from __future__ import division
-from __future__ import print_function
+from __future__ import division, print_function
 from builtins import object
 import time, copy
 import numpy as np
@@ -140,14 +139,15 @@ class Process(object):
         for varname in list(self.state.keys()):
             str1 += '  {0}: {1} \n'.format(varname, self.domains[varname].shape)
         str1 += 'The subprocess tree: \n'
-        str1 += walk.process_tree(self)
+        str1 += walk.process_tree(self, name=self.name)
         return str1
 
-    def __init__(self, state=None, domains=None, subprocess=None,
+    def __init__(self, name='Untitled', state=None, domains=None, subprocess=None,
                  lat=None, lev=None, num_lat=None, num_levels=None,
                  input=None, verbose=True, **kwargs):
         # verbose flag used to control text output at process creation time
         self.verbose = verbose
+        self.name = name
         # dictionary of domains. Keys are the domain names
         self.domains = _make_dict(domains, _Domain)
         #  If lat is given, create a simple domains
@@ -199,7 +199,11 @@ class Process(object):
 
         """
         if isinstance(procdict, Process):
-            self.add_subprocess('default', procdict)
+            try:
+                name = procdict.name
+            except:
+                name = 'default'
+            self.add_subprocess(name, procdict)
         else:
             for name, proc in procdict.items():
                 self.add_subprocess(name, proc)
@@ -441,8 +445,8 @@ class Process(object):
         Quantity is accessible in two ways:
 
             * as a process attribute, i.e. ``proc.name``
-            * as a member of the diagnostics dictionary,
-              i.e. ``proc.diagnostics['name']``
+            * as a member of the input dictionary,
+              i.e. ``proc.input['name']``
 
         Use attribute method to set values, e.g.
         ```proc.name = value ```
