@@ -5,8 +5,35 @@ from builtins import range
 import numpy as np
 import copy
 from climlab import constants as const
-from climlab.process.process import Process
-from climlab.utils.walk import walk_processes
+from .process import Process
+from climlab.utils import walk, attr_dict
+
+
+def couple(proclist, name='Parent'):
+    #  Union of the two state dictionaries
+    new_state = attr_dict.AttrDict()
+    new_input = attr_dict.AttrDict()
+    all_input = {}
+    all_diagnotics_list = []
+    timestep = const.seconds_per_year * 1E6  # very long!
+    for proc in proclist:
+        timestep = np.minimum(timestep, proc.timestep)
+        for key in proc.state:
+            new_state[key] = proc.state[key]
+        all_diagnotics_list += list(proc.diagnostics.keys())
+        for key in proc.input:
+            all_input[key] = proc.input[key]
+    for key in all_input:
+        if (key not in new_state) and (key not in all_diagnotics_list):
+            # This quantity is still a necessary input for the parent process
+            new_input[key] = all_input[key]
+    # The newly created parent process has the minimum timestep
+    coupled = TimeDependentProcess(state=new_state, timestep=timestep, name=name)
+    for proc in proclist:
+        coupled.add_subprocess(proc.name, proc)
+    for key in new_input:
+        coupled.add_input(key, new_input[key])
+    return coupled
 
 
 class TimeDependentProcess(Process):
@@ -77,6 +104,10 @@ class TimeDependentProcess(Process):
         self.topdown = topdown
         self.has_process_type_list = False
 
+    def __add__(self, other):
+        newparent = couple([self,other])
+        return newparent
+
     @property
     def timestep(self):
         """The amount of time over which :func:`step_forward` is integrating in unit seconds.
@@ -191,7 +222,7 @@ class TimeDependentProcess(Process):
                     self.timestep)
         #  Walk the subprocess tree and sum up all tendencies from subprocesses
         #   By walking with topdown=False we ensure that we don't miss anything
-        for (name, proc, level) in walk_processes(self,topdown=False):
+        for (name, proc, level) in walk.walk_processes(self,topdown=False):
             if proc.time['active_now']:
                 for subname, subproc in proc.subprocess.items():
                     for varname in subproc.tendencies:
@@ -256,7 +287,7 @@ class TimeDependentProcess(Process):
 
         """
         self.process_types = {'diagnostic': [], 'explicit': [], 'implicit': [], 'adjustment': []}
-        for name, proc, level in walk_processes(self, topdown=self.topdown):
+        for name, proc, level in walk.walk_processes(self, topdown=self.topdown):
             self.process_types[proc.time_type].append(proc)
         self.has_process_type_list = True
 
@@ -294,7 +325,7 @@ class TimeDependentProcess(Process):
 
         # Update all time counters for this and all subprocesses in the tree
         #  Also pass diagnostics up the process tree
-        for name, proc, level in walk_processes(self, ignoreFlag=True):
+        for name, proc, level in walk.walk_processes(self, ignoreFlag=True):
             if proc.time['active_now']:
                 proc._update_time()
                 for diagname, value in proc.diagnostics.items():
@@ -310,7 +341,7 @@ class TimeDependentProcess(Process):
         for n in range(num_iter):
             self.compute()
         #  Pass diagnostics up the process tree
-        for name, proc, level in walk_processes(self, ignoreFlag=True):
+        for name, proc, level in walk.walk_processes(self, ignoreFlag=True):
             for diagname, value in proc.diagnostics.items():
                 self.__setattr__(diagname, value)
 
